Change Log for OppiaMobile Platform Components — OppiaMobile 0.5.2 documentation

# Change Log for OppiaMobile Platform Components

The OppiaMobile platform consists of 3 core components (server, client app and the Moodle export block). This page summarises the currently released versions of each of these and the changelog history for each.

## OppiaMobile Server (on Django)

Current Version: 0.5.2

- OppiaMobile Server Change Log
  - v0.5.3 - not yet released
  - v0.5.2 - released: 26 Oct 2014
  - v0.5.1 - released: 30 Sept 2014
  - Previous Versions

## OppiaMobile Client App (Android)

Current Version: 48 (4.1.2)

- OppiaMobile Android App Change Log
  - v49 (4.1.3) - not yet released
  - v48 (4.1.2) - released: 1 Oct 2014

## OppiaMobile export block for Moodle

Current Version: v2014102900

- OppiaMobile Moodle Block Change Log
  - vX - not yet released
  - v2014102900 - released: 29 Oct 2014